%% input data
%input filename(s)
file = 'YL_Lus016940_opto-200518-150613';
folder = 'Pilots-161025-141653';
drive = 'E:\FIBER PHO matlab program';

%input timestamps before/after injection
ts_pre = 610;
ts_post = 630;
note_condition = 'sert DS sal';

%% extract and normalize data, downsample
%import and normalize data to dF/F:
[data_norm, data_raw] = FP_Control(drive, folder, file); %basic extraction of data
[bl_rec, ~, ~, bls, ~] = FP_Control_v2(drive, folder, file, 600, round(ts_pre.*data_norm.samplerate)); %adapted data with signal normalizes to baseline

%downsample 10x to decrease filesizes:
data_ds = downsample(bl_rec.data,10); %downsample output
sample_freq = data_norm.samplerate./10; %sampling frequency 

%% create output averages per 30s for excel
%bin the data to 30s periods
[binned_0to20,binned_0to20_last] = FP_Average_to_bins(data_ds(round((ts_post).*sample_freq) : round((ts_post+2000).*sample_freq)), sample_freq, 30);
[binned_min5to0,binned_min5to0_last] = FP_Average_to_bins(data_ds(round((ts_pre-301).*sample_freq) : round((ts_pre).*sample_freq)), sample_freq, 30);

%% plot the raw data trace
%plot data
figure;
plot(data_ds);

%modify axes
xlim([round((ts_post-300).*sample_freq) round((ts_post+2000).*sample_freq)]);
ylim([-0.05 0.25]);
ax = gca;
ax.XTick=([round((ts_post-300).*sample_freq) : round(300.*sample_freq) : round((ts_post+2000).*sample_freq)]);
ax.XTickLabel={'-5', '0', '5', '10', '15', '20', '25', '30', '35', '40', '45', '50'};

%standardize figure size
fig = gcf;
fig.Position = [186   349   566   264];

%draw lines at Y = 0 and X = 0, removes box, and adds title
line([ts_post.*sample_freq ts_post.*sample_freq], [-0.1 0.35], 'color' ,'r');
getxlim = xlim;
line([getxlim(1) getxlim(2)],[0 0], 'color' ,'k');
box off;
note_title =  strcat(file,'-',note_condition); 
title(note_title);


%% saves the data
% matlab file
save(strcat(note_title, '.mat'));

% figure as pdf
saveas(fig,note_title, 'pdf');
