function opt = mkcontopt(varargin)
% MKSPECGRAMOPT options for creating a cont object for display
%
% $$$        -method ('multitaper', 'specgram'-matlab defaults, i.e. hanning window)
% $$$        -nfft (512 bins)
% $$$        -window (500 samples)
% $$$        -noverlap (250 samples)
% $$$        -mt_NW - multitaper param (2)
% $$$        -mt_detrend ([], 'linear' or 'constant' - note different from 0!)
% $$$        ...
% $$$        -maxcols -max columns to compute, avoid blowing up (1000)

  opt = struct(...
      'method','multitaper',...
      'nfft',512,...
      'window_time',[],...
      'window_samp',[],...
      'multiply_by_f', false,...
      'overlap_frac',0.5,...
      'mt_NW', 2,...
      'mt_detrend', 'linear',...
      ...
      'maxcols', 1000);
  
  opt = parseArgsLite(varargin,opt);    

  if opt.overlap_frac < 0 || opt.overlap_frac >= 1,
    error('''overlap_frac'' must be >= 0 and < 1');
  end
  
  if ~any(strcmp(opt.method, {'specgram', 'multitaper'}))
    error('unsupported specgram ''method''');
  end