function fname = slprint(fig, fname, dpi)
% SLPRINT  print a spikeslpos figure to a .png file
%
% fname = slprint(fig,fname,dpi)
%
% fig: handle of figure to print (gcf)
% fname: filename (autogenerated from e.desc, sla.timewin...)
% dpi: dpi to use (same as screen resolution
  
  if ~exist('fig','var') || isempty(fig),
    fig = gcf;
  end
  
  if ~exist('dpi','var') || isempty(dpi),
    dpi = 0;
  end
  
  oldihc = get(gcf,'inverthardcopy');
  oldppm = get(gcf,'paperpositionmode');
  
  set(gcf,'inverthardcopy','off');
  set(gcf,'paperpositionmode','auto');

  panels = findobj(fig, 'type', 'uipanel');
  for panel = panels(:)'
    sla = getappdata(panel,'slargs');
    sld = getappdata(panel,'sldata');
    uistack(sld.ax,'top');
  end
  
  if ~exist('fname','var') || isempty(fname),
    format = '.png';
    fnamebase = [sla.ename '_' num2str(mean([sld.xstart sld.xend]),'%0.1f') 's_' ...
                 num2str(sla.timebinsize*1000,'%0.f') 'ms'];
    
    
    fnamenum = '';
    for k=2:20; 
      if ~exist([fnamebase fnamenum format],'file'),  
        break;
      else
        fnamenum = ['_' int2str(k)];
      end
    end
    fname = [fnamebase fnamenum format];
    
  end
  
  % -r0 says use screen resolution (default is 150dpi)
  print(fig, '-dpng', ['-r' num2str(dpi)],fname);
  
  uistack(sld.ax,'bottom');
  set(gcf,'inverthardcopy',oldihc);
  set(gcf,'paperpositionmode',oldppm);
  